@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
-# :Id: $Id: latex2mathml.py 7668 2013-06-04 12:46:30Z milde $
+# :Id: $Id: latex2mathml.py 7865 2015-04-12 10:06:43Z milde $
 # :Copyright: © 2010 Günter Milde.
 #             Based on rst2mathml.py from the latex_math sandbox project
 #             © 2005 Jens Jørgen Mortensen
@@ -558,3 +558,14 @@ def handle_keyword(name, node, string):
         raise SyntaxError('Unknown LaTeX command: ' + name)
 
     return node, skip
+
+def tex2mathml(tex_math, inline=True):
+    """Return string with MathML code corresponding to `tex_math`. 
+    
+    `inline`=True is for inline math and `inline`=False for displayed math.
+    """
+    
+    mathml_tree = parse_latex_math(tex_math, inline=inline)
+    return ''.join(mathml_tree.xml())
+
+    
